@@ -1,4 +1,6 @@
-from recorder.config import DEFAULT_CONFIG_PATH, DEFAULT_OUTPUT_FOLDER
+from recorder.config import (
+    DEFAULT_CONFIG_PATH, DEFAULT_OUTPUT_FOLDER, DEFAULT_TEST_OUTPUT_FOLDER
+    )
 from recorder.device import Device, DEVICE_CLASSES
 from recorder.listener import Listener, LISTENER_CLASSES
 from recorder.io import yaml_dump
@@ -22,6 +24,12 @@ DEFAULT_OUTPUT_FOLDER_OPTION = typer.Option(
     Path to a folder where the recorded data and the recording configuration
     will be stored."""
     )
+DEFAULT_TEST_OUTPUT_FOLDER_OPTION = typer.Option(
+    DEFAULT_TEST_OUTPUT_FOLDER,
+    help="""
+    Path to a folder where the recorded data and the recording configuration
+    will be stored."""
+    )
 DEFAULT_CONFIG_PATH_OPTION = typer.Option(
     DEFAULT_CONFIG_PATH,
     help="Path to a `yaml` config file. Run `config` command to generate one."
@@ -31,14 +39,15 @@ DEVICE_CLASS_ARGUMENT = typer.Argument(
     metavar='DEVICE_CLASS',
     help=(
         "Case independent name of the device class to use. Available options: "
-        f"{[d for d in DEVICE_CLASSES.keys()]}."
+        f"{list(DEVICE_CLASSES.keys())}."
         )
     )
 DEVICE_ID_ARGUMENT = typer.Argument(
     None,
     metavar='DEVICE_ID',
     help=(
-        "Numerical id of the device to use. Use the show command to see the available devices for each device class."
+        "Numerical id of the device to use. Use the show command to see the "
+        "available devices for each device class."
         )
     )
 LISTENER_CLASS_ARGUMENT = typer.Argument(
@@ -46,7 +55,7 @@ LISTENER_CLASS_ARGUMENT = typer.Argument(
     metavar='LISTENER_CLASS',
     help=(
         "Case independent name of the listener class to use. Available "
-        f"options: {[d for d in DEVICE_CLASSES.keys()]}."
+        f"options: {list(DEVICE_CLASSES.keys())}."
         )
     )
 VERBOSE_OPTION = typer.Option(False, "--verbose", "-v", help="Verbose output.")
@@ -88,8 +97,8 @@ def get_listener_class(name: str) -> Listener:
 
 @app.command(help="Display the available devices")
 def show(
-        device_class: Optional[str] = DEVICE_CLASS_ARGUMENT,
-        verbose: bool = VERBOSE_OPTION
+    device_class: Optional[str] = DEVICE_CLASS_ARGUMENT,
+    verbose: bool = VERBOSE_OPTION,
     ):
     if device_class:
         device_classes = [get_device_class(device_class)]
@@ -129,18 +138,18 @@ def config_device_class(device: Device) -> dict:
 
 @app.command(help="Create a configuration `yaml` file.")
 def config(output: Path = DEFAULT_CONFIG_PATH_OPTION) -> dict:
-    config = {}
+    _config = {}
     for name, device_class in DEVICE_CLASSES.items():
         device_config = config_device_class(device_class)
         if device_config:
-            config[name] = device_config
-    yaml_dump(config, to_file=output)
+            _config[name] = device_config
+    yaml_dump(_config, to_file=output)
     typer.echo(
         f"Configuration file written to {output}, it can be edited manually. "
         "Check the repository for an explained example file "
         "https://github.com/AcousticOdometry/VAO-recorder/blob/main/example-config.yaml"
         )
-    return config
+    return _config
 
 
 def get_config(path: Path = DEFAULT_CONFIG_PATH) -> dict:
@@ -159,8 +168,8 @@ def record(
     config_path: Optional[Path] = DEFAULT_CONFIG_PATH_OPTION,
     output_folder: Optional[Path] = DEFAULT_OUTPUT_FOLDER_OPTION,
     ):
-    config = get_config(config_path)
-    recorder = Recorder(config, output_folder)
+    _config = get_config(config_path)
+    recorder = Recorder(_config, output_folder)
     if typer.confirm("Recording ready, start?", default=True):
         output_folder = recorder(seconds=seconds)
         typer.echo(f"Recording finished, data saved to {output_folder}")
@@ -173,8 +182,8 @@ def listen(
     output_folder: Optional[Path] = DEFAULT_OUTPUT_FOLDER_OPTION,
     # TODO pass kwargs to listener. Or make subcommands for each listener
     ):
-    config = get_config(config_path)
-    recorder = Recorder(config, output_folder, setup_name=False)
+    _config = get_config(config_path)
+    recorder = Recorder(_config, output_folder, setup_name=False)
     listener = get_listener_class(listener_class)(recorder)
     listener.listen()
 
@@ -184,37 +193,37 @@ def test(
     device_class: Optional[str] = DEVICE_CLASS_ARGUMENT,
     device_id: Optional[int] = DEVICE_ID_ARGUMENT,
     config_path: Optional[Path] = DEFAULT_CONFIG_PATH_OPTION,
-    output_folder: Optional[Path] = DEFAULT_OUTPUT_FOLDER_OPTION,
+    output_folder: Optional[Path] = DEFAULT_TEST_OUTPUT_FOLDER_OPTION,
     ):
-    if not device_id:
-        config = get_config(config_path)
+    if device_id is None:
+        _config = get_config(config_path)
         if device_class:
             # Filter to only the devices of the given class
-            config = Config({
+            _config = Config({
                 d_class: ds
-                for d_class, ds in config.items() if d_class == device_class
+                for d_class, ds in _config.items() if d_class == device_class
                 })
-            if not config:
+            if not _config:
                 typer_warn(
                     f"No device of class `{device_class}` found in "
                     f"{config_path}"
                     )
                 return
-        recorder = Recorder(config, output_folder)
+        recorder = Recorder(_config, output_folder)
         output_folder = recorder(seconds=5)
-        for _device_class in config.keys():
+        for _device_class in _config.keys():
             DEVICE_CLASSES[_device_class].show_results(output_folder)
     else:
         # Both device_class and device_id are given
         devices = get_device_class(device_class).find()
         try:
-            device = devices[device_id]
+            device = devices[str(device_id)]
         except KeyError:
             raise AttributeError(
                 f'Invalid device id `{device_id}` for class `{device_class}`'
                 )
-        config = Config({device_class: {device_id: device}})
-        recorder = Recorder(config, output_folder)
+        _config = Config({device_class: {device_id: device}})
+        recorder = Recorder(_config, output_folder)
         output_folder = recorder(seconds=5)
         DEVICE_CLASSES[device_class].show_results(output_folder)
 
@@ -228,4 +237,4 @@ def main():
 
 
 if __name__ == '__main__':
-    main()
\ No newline at end of file
+    main()
